@@ -32,7 +32,10 @@ TRUE = jnp.bool_(True)
 @dataclass
 class State(core.State):
     curr_player: jnp.ndarray = ZERO
-    reward: jnp.ndarray = jnp.float32(0)
+    observation: jnp.ndarray = jnp.zeros((10, 10, 4), dtype=jnp.bool_)
+    reward: jnp.ndarray = jnp.zeros(
+        1, dtype=jnp.float32
+    )  # 1d array for the same API as other multi-agent games
     terminated: jnp.ndarray = FALSE
     legal_action_mask: jnp.ndarray = jnp.zeros(6, dtype=jnp.bool_)
     rng: jax.random.KeyArray = jax.random.PRNGKey(0)
@@ -60,8 +63,8 @@ class MinAtarAsterix(core.Env):
         self.minatar_version: Literal["v0", "v1"] = minatar_version
         self.sticky_action_prob: float = sticky_action_prob
 
-    def init(self, rng: jax.random.KeyArray) -> State:
-        return State(rng=rng)  # type: ignore
+    def _init(self, key: jax.random.KeyArray) -> State:
+        return State(rng=key)  # type: ignore
 
     def _step(self, state: core.State, action) -> State:
         assert isinstance(state, State)
@@ -81,6 +84,10 @@ class MinAtarAsterix(core.Env):
     def num_players(self):
         return 1
 
+    @property
+    def reward_range(self) -> Tuple[float, float]:
+        return 0.0, jnp.inf
+
 
 def step(
     state: State,
@@ -227,7 +234,7 @@ def _step_det_at_non_terminal(
 
     next_state = State(
         terminated=terminal,
-        reward=r,
+        reward=r[jnp.newaxis],  # 1-d array
         player_x=player_x,
         player_y=player_y,
         entities=entities,
